#
# spec file for package python-bloscpack
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-bloscpack
Version:        0.9.0
Release:        3.2
Summary:        Command line interface to and serialization format for Blosc
License:        MIT
Group:          Development/Languages/Python
Url:            https://github.com/Blosc/bloscpack
Source:         https://pypi.python.org/packages/source/b/bloscpack/bloscpack-%{version}.tar.gz
BuildRequires:  python-blosc >= 1.2.7
BuildRequires:  python-devel
BuildRequires:  python-numpy
BuildRequires:  python-setuptools
BuildRequires:  python-six
# Test requirements
BuildRequires:  python-mock
BuildRequires:  python-nose
Requires:       python-blosc >= 1.2.7
Requires:       python-numpy
Requires:       python-six
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
BuildRequires:  python-ordereddict
Requires:       python-ordereddict
%else
BuildArch:      noarch
%endif

%description
Command line interface to and serialization format for Blosc, a high
performance, multi-threaded, blocking and shuffling compressor. Uses
python-blosc bindings to interface with Blosc. Also comes with native
support for efficiently serializing and deserializing Numpy arrays.

%prep
%setup -q -n bloscpack-%{version}

# Remove unneeded shebangs
for lib in bloscpack/*.py; do
    sed '1{\@^#!/usr/bin/env python@d}' $lib > $lib.new &&
    touch -r $lib $lib.new &&
    mv $lib.new $lib
done

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

# Prepare for update-alternatives usage
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
mv %{buildroot}%{_bindir}/blpk %{buildroot}%{_bindir}/blpk-%{py_ver}
ln -s -f %{_sysconfdir}/alternatives/blpk %{buildroot}%{_bindir}/blpk
# create a dummy target for /etc/alternatives/blpk
touch %{buildroot}%{_sysconfdir}/alternatives/blpk

%post
%_sbindir/update-alternatives \
   --install %{_bindir}/blpk blpk %{_bindir}/blpk-%{py_ver} 30

%postun
if [ $1 -eq 0 ] ; then
    %_sbindir/update-alternatives --remove blpk %{_bindir}/blpk-%{py_ver}
fi

# some tests are architecture-specific
%check
%ifarch ppc64 ppc64le
nosetests test -e 'test_offsets' -e 'test_append_fp' -e 'test_decode_blosc_header'
%endif
%ifarch i586 aarch64 
nosetests test -e 'test_offsets' -e 'test_append_fp'
%endif
%ifarch x86_64
nosetests test
%endif

%files
%defattr(-,root,root,-)
%doc README.rst
%{_bindir}/blpk
%{_bindir}/blpk-%{py_ver}
%ghost %{_sysconfdir}/alternatives/blpk
%{python_sitelib}/*

%changelog
* Mon Aug 31 2015 toddrme2178@gmail.com
- Fix building on Python 2.6 (SLE 11)
* Mon Aug 31 2015 toddrme2178@gmail.com
- Fix tests on archs other than x86_64
* Mon Aug 31 2015 toddrme2178@gmail.com
- Initial version
